Description Usage Arguments Value
This function analyzes semicompeting risks data and gives the estimators of direct and indirect effects, along with their variances.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 |
df |
a data frame with designated column order: |
effect |
the causal effect to be estimated. Choices are |
intervention |
numeric vector with two elements. Default is |
cal_level |
the level |
myunit |
the length to be considered as one unit. Default is |
downsample |
indicates how many consecutive event should be considered as one event. Default is |
sen_ana |
doing sensitivity analysis or not. Default is |
get_variance |
the method to compute the variance. Choices are |
boot_times |
the times of bootstrap. Default is |
timer |
will show the progress. Default is |
num_of_cores |
the number of cores assigned. Default is |
plot_result |
will show some primary result. Default is |
threshold |
specifies if a logistic regression converge or not. Default is |
CASCR returns a list with components specified by effect.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.